"use strict";
exports.id = 459;
exports.ids = [459];
exports.modules = {

/***/ 32731:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
const process_command_args_1 = __webpack_require__(52369);
const assert_iac_options_flag_1 = __webpack_require__(68590);
const measurable_methods_1 = __webpack_require__(78272);
const config_1 = __webpack_require__(22541);
const drift_1 = __webpack_require__(26445);
const legacyError = __webpack_require__(79407);
async function drift(...args) {
    var _a, _b;
    const { options, paths } = process_command_args_1.processCommandArgs(...args);
    if (options.iac != true) {
        return legacyError('drift');
    }
    const orgPublicId = (_a = options.org) !== null && _a !== void 0 ? _a : config_1.default.org;
    const iacOrgSettings = await measurable_methods_1.getIacOrgSettings(orgPublicId);
    if (!((_b = iacOrgSettings.entitlements) === null || _b === void 0 ? void 0 : _b.iacDrift)) {
        throw new assert_iac_options_flag_1.UnsupportedEntitlementCommandError('drift', 'iacDrift');
    }
    try {
        const args = drift_1.parseArgs(paths, options);
        const ret = await drift_1.driftctl(args);
        process.exit(ret);
    }
    catch (e) {
        const err = new Error('Error running `iac drift` ' + e);
        return Promise.reject(err);
    }
}
exports.default = drift;


/***/ }),

/***/ 63011:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.hasFeatureFlag = exports.isFeatureFlagSupportedForOrg = void 0;
const request_1 = __webpack_require__(52050);
const api_token_1 = __webpack_require__(95181);
const config_1 = __webpack_require__(22541);
const common_1 = __webpack_require__(53110);
const errors_1 = __webpack_require__(55191);
async function isFeatureFlagSupportedForOrg(featureFlag, org) {
    const response = await request_1.makeRequest({
        method: 'GET',
        headers: {
            Authorization: api_token_1.getAuthHeader(),
        },
        qs: common_1.assembleQueryString({ org }),
        url: `${config_1.default.API}/cli-config/feature-flags/${featureFlag}`,
        gzip: true,
        json: true,
    });
    return response.body;
}
exports.isFeatureFlagSupportedForOrg = isFeatureFlagSupportedForOrg;
async function hasFeatureFlag(featureFlag, options) {
    const { code, error, ok } = await isFeatureFlagSupportedForOrg(featureFlag, options.org);
    if (code === 401 || code === 403) {
        throw errors_1.AuthFailedError(error, code);
    }
    return ok;
}
exports.hasFeatureFlag = hasFeatureFlag;


/***/ }),

/***/ 68620:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.projectTypeByFileType = exports.TEST_SUPPORTED_IAC_PROJECTS = exports.IacProjectType = void 0;
var IacProjectType;
(function (IacProjectType) {
    IacProjectType["K8S"] = "k8sconfig";
    IacProjectType["TERRAFORM"] = "terraformconfig";
    IacProjectType["CLOUDFORMATION"] = "cloudformationconfig";
    IacProjectType["ARM"] = "armconfig";
    IacProjectType["CUSTOM"] = "customconfig";
    IacProjectType["MULTI_IAC"] = "multiiacconfig";
})(IacProjectType = exports.IacProjectType || (exports.IacProjectType = {}));
exports.TEST_SUPPORTED_IAC_PROJECTS = [
    IacProjectType.K8S,
    IacProjectType.TERRAFORM,
    IacProjectType.CLOUDFORMATION,
    IacProjectType.ARM,
    IacProjectType.MULTI_IAC,
    IacProjectType.CUSTOM,
];
exports.projectTypeByFileType = {
    yaml: IacProjectType.K8S,
    yml: IacProjectType.K8S,
    json: IacProjectType.K8S,
    tf: IacProjectType.TERRAFORM,
};


/***/ }),

/***/ 43458:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.makeValidateTerraformRequest = exports.validateK8sFile = exports.getFileType = void 0;
//TODO(orka): take out into a new lib
const debugLib = __webpack_require__(15158);
const cloud_config_parser_1 = __webpack_require__(98611);
const errors_1 = __webpack_require__(55191);
const request_1 = __webpack_require__(52050);
const api_token_1 = __webpack_require__(95181);
const config_1 = __webpack_require__(22541);
const debug = debugLib('snyk-detect');
const requiredK8SObjectFields = ['apiVersion', 'kind', 'metadata'];
function getFileType(filePath) {
    const filePathSplit = filePath.split('.');
    return filePathSplit[filePathSplit.length - 1].toLowerCase();
}
exports.getFileType = getFileType;
function parseFileContent(fileContent, filePath) {
    const fileType = getFileType(filePath);
    switch (fileType) {
        case 'yaml':
        case 'yml':
        case 'json':
            try {
                return cloud_config_parser_1.parseFileContent(fileContent);
            }
            catch (e) {
                if (fileType === 'json') {
                    debug('Failed to parse iac config as a JSON');
                }
                else {
                    debug('Failed to parse iac config as a YAML');
                }
            }
            break;
        default:
            debug(`Unsupported iac config file type (${fileType})`);
    }
    return undefined;
}
// This function validates that there is at least one valid doc with a k8s object kind.
// If there is a doc with a supported kind, but invalid, we should fail
// The function return true if the yaml is a valid k8s one, or false otherwise
function validateK8sFile(fileContent, filePath, fileName) {
    const k8sObjects = parseFileContent(fileContent, filePath);
    if (!k8sObjects) {
        return { isValidFile: false, reason: errors_1.IllegalIacFileErrorMsg(fileName) };
    }
    let numOfSupportedKeyDocs = 0;
    for (let i = 0; i < k8sObjects.length; i++) {
        const k8sObject = k8sObjects[i];
        if (!k8sObject || !k8sObject.kind) {
            continue;
        }
        numOfSupportedKeyDocs++;
        for (const key of requiredK8SObjectFields) {
            if (!k8sObject[key]) {
                debug(`Missing required field (${key})`);
                return {
                    isValidFile: false,
                    reason: errors_1.IllegalIacFileErrorMsg(fileName),
                };
            }
        }
    }
    if (numOfSupportedKeyDocs === 0) {
        return {
            isValidFile: false,
            reason: errors_1.NotSupportedIacFileErrorMsg(fileName),
        };
    }
    debug(`k8s config found (${filePath})`);
    return { isValidFile: true, reason: '' };
}
exports.validateK8sFile = validateK8sFile;
async function makeValidateTerraformRequest(terraformFileContent) {
    var _a, _b;
    const response = await request_1.makeRequest({
        body: {
            contentBase64: Buffer.from(terraformFileContent).toString('base64'),
        },
        url: `${config_1.default.API}/iac-validate/terraform`,
        method: 'POST',
        json: true,
        headers: {
            Authorization: `token ${api_token_1.api()}`,
        },
    });
    // Token may have expired, so we need to ask the client to re-auth.
    if (response.res.statusCode === 401) {
        throw new errors_1.MissingApiTokenError();
    }
    if (!response.res.statusCode ||
        (response.res.statusCode < 200 && response.res.statusCode >= 300)) {
        debug(`internal server error - ${response.body}`);
        throw new errors_1.InternalServerError('Error occurred validating terraform file');
    }
    const { body } = response;
    return {
        isValidFile: (_a = body === null || body === void 0 ? void 0 : body.isValidTerraformFile) !== null && _a !== void 0 ? _a : false,
        reason: (_b = body === null || body === void 0 ? void 0 : body.reason) !== null && _b !== void 0 ? _b : '',
    };
}
exports.makeValidateTerraformRequest = makeValidateTerraformRequest;


/***/ }),

/***/ 87491:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.makeDirectoryIterator = void 0;
const fs = __webpack_require__(35747);
const path_1 = __webpack_require__(85622);
/**
 * Walk the provided directory tree, depth first, yielding the matched filename
 * to the caller. An optional `maxDepth` argument can be provided to limit how
 * deep in the file tree the search will go.
 */
function* makeDirectoryIterator(root, options = {}) {
    if (!isDirectory(root)) {
        throw new Error(`Path "${root}" is not a directory`);
    }
    // Internal function to allow us to track the recursion depth.
    function* walk(dirpath, currentDepth) {
        const filenames = fs.readdirSync(dirpath);
        for (const filename of filenames) {
            // NOTE: We filter filenames that start with a period to maintain
            // backwards compatibility with the original implementation that used the
            // "glob" package.
            if (!options.includeDotfiles && filename.startsWith('.')) {
                continue;
            }
            const resolved = path_1.resolve(dirpath, filename);
            if (isDirectory(resolved)) {
                // Skip this directory if max depth has been reached.
                if (options.maxDepth === currentDepth) {
                    continue;
                }
                yield* walk(resolved, currentDepth + 1);
            }
            else {
                yield resolved;
            }
        }
    }
    yield* walk(root, 1);
}
exports.makeDirectoryIterator = makeDirectoryIterator;
// NOTE: We use isDirectory here instead of isLocalFolder() in order to
// follow symlinks and match the original glob() implementation.
function isDirectory(path) {
    try {
        // statSync will resolve symlinks, lstatSync will not.
        return fs.statSync(path).isDirectory();
    }
    catch (e) {
        return false;
    }
}


/***/ }),

/***/ 8820:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.findAndLoadPolicy = void 0;
const snykPolicyLib = __webpack_require__(70535);
const debugModule = __webpack_require__(15158);
const _1 = __webpack_require__(32615);
const analytics = __webpack_require__(82744);
const debug = debugModule('snyk');
async function findAndLoadPolicy(root, scanType, options, pkg, scannedProjectFolder) {
    const isDocker = scanType === 'docker';
    const isNodeProject = ['npm', 'yarn'].includes(scanType);
    // monitor
    let policyLocations = [
        options['policy-path'] || scannedProjectFolder || root,
    ];
    if (isDocker) {
        policyLocations = policyLocations.filter((loc) => loc !== root);
    }
    else if (isNodeProject) {
        // TODO: pluckPolicies expects a package.json object to
        // find and apply policies in node_modules
        policyLocations = policyLocations.concat(_1.pluckPolicies(pkg));
    }
    debug('Potential policy locations found:', policyLocations);
    analytics.add('policies', policyLocations.length);
    analytics.add('policyLocations', policyLocations);
    if (policyLocations.length === 0) {
        return;
    }
    let policy;
    try {
        policy = await snykPolicyLib.load(policyLocations, options);
    }
    catch (err) {
        // note: inline catch, to handle error from .load
        // if the .snyk file wasn't found, it is fine
        if (err.code !== 'ENOENT' && err.code !== 'ENOTDIR') {
            throw err;
        }
    }
    return policy;
}
exports.findAndLoadPolicy = findAndLoadPolicy;


/***/ }),

/***/ 32615:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
var pluck_policies_1 = __webpack_require__(68247);
Object.defineProperty(exports, "pluckPolicies", ({ enumerable: true, get: function () { return pluck_policies_1.pluckPolicies; } }));
var find_and_load_policy_1 = __webpack_require__(8820);
Object.defineProperty(exports, "findAndLoadPolicy", ({ enumerable: true, get: function () { return find_and_load_policy_1.findAndLoadPolicy; } }));


/***/ }),

/***/ 68247:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.pluckPolicies = void 0;
const flatten = __webpack_require__(5800);
function pluckPolicies(pkg) {
    if (!pkg) {
        return [];
    }
    if (pkg.snyk) {
        return pkg.snyk;
    }
    if (!pkg.dependencies) {
        return [];
    }
    return flatten(Object.keys(pkg.dependencies)
        .map((name) => pluckPolicies(pkg.dependencies[name]))
        .filter(Boolean));
}
exports.pluckPolicies = pluckPolicies;


/***/ })

};
;
//# sourceMappingURL=459.index.js.map